# Joker

Joking is a python library for getting random dad jokes and more kinds of jokes

![](https://img.shields.io/badge/build-Passing-green?style=for-the-badge) [![forthebadge](https://forthebadge.com/images/badges/gluten-free.svg)](https://forthebadge.com) [![forthebadge](https://forthebadge.com/images/badges/powered-by-electricity.svg)](https://forthebadge.com) [![forthebadge](https://forthebadge.com/images/badges/built-with-love.svg)](https://forthebadge.com) ![](https://img.shields.io/badge/License-MIT-orange?style=for-the-badge) 


# Installation

you can install it by using the [pip](https://pip.pypa.io/en/stable/) package manager

```bash
pip install Joking
```

# How to Use

```python
random_dad_joke() #prints out a random dad joke
```

```python
programming_joke() #prints a random programming joke
```

```python
random_joke() #prints a random joke
```

# How it works

It works by web scraping https://icanhazdadjoke.com/ and using version 2 of jokeapi.dev